Paralelo CS Qlik API SDK for Python! — Paralelo CS Qlik API SDK for Python 0.2.5 documentation

# Paralelo CS Qlik API SDK for Python!

This documentation cover how you deal with the QlikAPI. The QlikAPI is a high level api in order to call methods from QLIK API.

## First step

Here how you install and setup the high level Qlik API.

    pip install paralelocs-qlikapi

Work with QlikAPI instance, the high level API.

    from paralelocs_qlikapi.api.api import QlikAPI

- Getting started
- paralelocs_qlikapi.api package
  - paralelocs_qlikapi.api.api module
  - paralelocs_qlikapi.api.auth module
- paralelocs_qlikapi.method package
  - paralelocs_qlikapi.method.app module
  - paralelocs_qlikapi.method.base module
  - paralelocs_qlikapi.method.reloadtask module
  - paralelocs_qlikapi.method.stream module
  - paralelocs_qlikapi.method.tag module
  - paralelocs_qlikapi.method.task module

# Indices and tables

- Index

- Module Index

- Search Page